import { Component } from "@angular/core";
import { DataService } from "./data.service";

import * as wjcCore from "@grapecity/wijmo";
import * as wjcGrid from "@grapecity/wijmo.grid";
import * as wjcGridDetail from "@grapecity/wijmo.grid.detail";
import * as wjcOdata from "@grapecity/wijmo.odata";

@Component({
	selector: "app-root",
	templateUrl: "app.component.html",
	styles: ["app.component.css"],
	providers: [DataService]
})
export class AppComponent {
	categories: wjcOdata.ODataCollectionView;
	products: wjcCore.CollectionView;

	// DataSvc will be passed by derived classes
	constructor(private dataSvc: DataService) {
		this.categories = this.dataSvc.getCategories();
	}

	getProduct(catID: number) {
		this.products = this.dataSvc.getProduct(catID);
	}

	initGrid(grid: wjcGrid.FlexGrid) {
		var self = this;
		new wjcGridDetail.FlexGridDetailProvider(grid, {
			createDetailCell: function(row) {
				var catId = row.dataItem.CategoryID;
				var products = self.dataSvc.getProduct(catId);

				// First div is to show the user that data is loading
				// Second is to create the grid
				var cell = wjcCore.createElement(`<div>
					<div>Loading......</div>
					<div style="display: none"></div>
				</div>`);
				var gridChild = new wjcGrid.FlexGrid(cell.children[1], {
					columns: [
						{ header: "Name", binding: "ProductName", width: "*" },
						{
							header: "Oty/Unit",
							binding: "QuantityPerUnit",
							width: "*"
						},
						{ header: "Unit Price", binding: "UnitPrice" },
						{ header: "Discontinued", binding: "Discontinued" }
					],
					headersVisibility: wjcGrid.HeadersVisibility.Column,
					isReadOnly: true,
					autoGenerateColumns: false
				});

				products.sourceCollectionChanged.addHandler(function(s, e) {
					var c0 = cell.children[0] as HTMLDivElement;
					c0.style.display = "none";
					gridChild.itemsSource = products;
					gridChild.hostElement.style.display = "block";
					grid.autoSizeRows();
					gridChild.invalidate();
				});
				return cell;
			}
		});
	}
}
